@@ -11,7 +11,6 @@ class Response(ResponseType):
     
     def getOrigin(self):
         try: 
-            
             split = self.url.split(".")
             domain = split[1]
             subdomain = split[0]
@@ -23,5 +22,5 @@ class Response(ResponseType):
     def debug_init(self):
         Terminal.put(f"{self.url} - {bcolors.OKGREEN}success{bcolors.ENDC}")
     
-    def __str__(self) -> None:
+    def __str__(self) -> str:
         return f"Response({self.url[0:10]})"
\ No newline at end of file
